# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/tobinjones/pep723widget/compare/35f1bc40396d194b3a5b77d54b47eba1ffef1b8e...a5fe55959fd089acfeba716cec577bbe9f50871b))

### Enhancements made

- Add PEP 723 notebook viewer extension [#1](https://github.com/tobinjones/pep723widget/pull/1) ([@tobinjones](https://github.com/tobinjones))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/tobinjones/pep723widget/graphs/contributors?from=2025-07-14&to=2025-07-14&type=c))

[@tobinjones](https://github.com/search?q=repo%3Atobinjones%2Fpep723widget+involves%3Atobinjones+updated%3A2025-07-14..2025-07-14&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->
